=====
Usage
=====

Creating notifications
======================

You must do three things to successfully create a notification:

* Subclass ``Notification`` in order to get the model fields.
* Use the ``NotificationMixin`` to get the basic methods.
* Override some methods to provide the minimal functionality.

